package com.ruoyi.model.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.model.domain.AppletOrder;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

/**
 * 订单信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface AppletOrderMapper extends BaseMapper<AppletOrder> {
    /**
     * 查询订单信息
     * 
     * @param id 订单信息主键
     * @return 订单信息
     */
    public AppletOrder selectAppletOrderById(Long id);

    public AppletOrder selectAppletOrderByOrderId(@Param("orderId") Long orderId);

    /**
     * 查询订单信息列表
     * 
     * @param appletOrder 订单信息
     * @return 订单信息集合
     */
    public List<AppletOrder> selectAppletOrderList(AppletOrder appletOrder);
    public List<AppletOrder> selectAppletOrderListLikeUserIdJson(AppletOrder appletOrder);

    /**
     * 新增订单信息
     * 
     * @param appletOrder 订单信息
     * @return 结果
     */
    public int insertAppletOrder(AppletOrder appletOrder);

    /**
     * 修改订单信息
     * 
     * @param appletOrder 订单信息
     * @return 结果
     */
    public int updateAppletOrder(AppletOrder appletOrder);

    /**
     * 删除订单信息
     * 
     * @param id 订单信息主键
     * @return 结果
     */
    public int deleteAppletOrderById(Long id);

    /**
     * 批量删除订单信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppletOrderByIds(Long[] ids);
}
